@@ -1,10 +1,9 @@
 dimActive <-
 function(res) {
-    analyse = whichFacto(res)
-    if(!analyse %in% c("PCA", "CA", "CaGalt", "MCA", "MFA", "DMFA", "FAMD", "GPA", "HCPC"))
+  analyse = whichFacto(res)
+  if(!analyse %in% c("PCA", "CA", "CaGalt", "MCA", "MFA", "DMFA", "FAMD", "GPA", "HCPC","HCPCshiny"))
     {return(warning("the parameter 'res' has to be an object of class 'PCA', 'CA', 'CaGalt', 'MCA', 'MFA', 'DMFA', 'FAMD', 'GPA' or 'HCPC'"))}
-    param = getParam(res)
-    
+	param = getParam(res)
     switch(analyse,
            PCA = {
              c(param$ind, param$var)
@@ -20,7 +19,9 @@ function(res) {
              c(param$ind, length(param$modalites))
            },
            
-           MFA = {},
+           MFA = {
+		     c(param$ind, sum(param$group))
+		  },
            
            HMFA = {},
            
